"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeyGenerators = void 0;
const uuid_1 = require("uuid");
/**
 * A selection of predefined {@link GeneratorFunc} functions to choose from.
 */
class KeyGenerators {
}
exports.KeyGenerators = KeyGenerators;
/**
 * Use the existing key.  Useful when adding elements to an array that already has keys.
 * If used, will usually be the first generator provided.
 *
 * @return GeneratorFunc
 */
KeyGenerators.existingKey = () => (obj) => obj.key || undefined; // eslint-disable-line @typescript-eslint/no-explicit-any
/**
 * A property extractor, allowing the objects to be walked until the leaf node is extracted.
 *
 * @param {string | string[]} propPath - The properties to traverse through the objects.
 * @return GeneratorFunc
 */
KeyGenerators.fromPropertyPath = (propPath) => (obj // eslint-disable-line @typescript-eslint/no-explicit-any
) => {
    const path = Array.isArray(propPath) ? propPath : propPath.split('.');
    const target = path.reduce((prev, prop) => prev[prop], obj);
    return !target || typeof target === 'object' ? '' : String(target);
};
/**
 * Generate a UUID (v4).  This is always used as a fallback.
 *
 * @return GeneratorFunc
 */
KeyGenerators.uuid = () => () => uuid_1.v4();
/**
 * A fallback generator.  Since this is the automatic fallback, it should guarantee unique values.
 *
 * @return GeneratorFunc
 */
KeyGenerators._fallback = KeyGenerators.uuid;
//# sourceMappingURL=keyGenerators.js.map