"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const keyGenerators_1 = require("./keyGenerators");
const testElement = {
    id: 23,
    name: "Dave Hughes",
    profile: {
        username: "dhughes"
    }
};
describe('existingKey', () => {
    const generator = keyGenerators_1.KeyGenerators.existingKey();
    it('returns a function', () => {
        expect(typeof generator).toBe('function');
    });
    it('uses existing key', () => {
        const existingKey = "existingKey";
        const elementWithKey = { ...testElement };
        elementWithKey.key = existingKey;
        expect(generator(elementWithKey)).toBe(existingKey);
    });
    it('is undefined for blank key', () => {
        const elementWithKey = { ...testElement };
        elementWithKey.key = "";
        expect(generator(elementWithKey)).toBeUndefined();
    });
    it('is undefined for non-existing key', () => {
        const elementWithKey = { ...testElement };
        elementWithKey.key = undefined;
        expect(generator(elementWithKey)).toBeUndefined();
    });
});
describe('fromPropertyPath (dot notation)', () => {
    const generator = keyGenerators_1.KeyGenerators.fromPropertyPath("");
    it('returns a function', () => {
        expect(typeof generator).toBe('function');
    });
    it.todo('is undefined when path leads to object', () => {
        expect(generator(testElement)).toBe("");
    });
    it.todo('is undefined when path leads does not exist', () => {
        expect(generator(testElement)).toBe("");
    });
});
describe('fromPropertyPath (array notation)', () => {
    const generator = keyGenerators_1.KeyGenerators.fromPropertyPath([]);
    it('returns a function', () => {
        expect(typeof generator).toBe('function');
    });
    it.todo('is undefined when path leads to object', () => {
        expect(generator(testElement)).toBe("");
    });
    it.todo('is undefined when path leads does not exist', () => {
        expect(generator(testElement)).toBe("");
    });
});
describe('uuid', () => {
    const uuidMatcher = /[0-9A-F]{8}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{12}/i;
    const generator = keyGenerators_1.KeyGenerators.uuid();
    it('returns a function', () => {
        expect(typeof generator).toBe('function');
    });
    it('generates a UUID', () => {
        expect(generator(testElement)).toMatch(uuidMatcher);
    });
    it('generates unique UUIDs every time', () => {
        const uuidSet = new Set();
        const n = 10;
        for (let i = 0; i < n; i++) {
            uuidSet.add(generator(testElement));
        }
        expect(uuidSet.size).toBe(n);
        uuidSet.forEach(((value) => expect(value).toMatch(uuidMatcher)));
    });
});
describe('_fallback', () => {
    it('is an alias for KeyGenerators.uuid()', () => {
        expect(keyGenerators_1.KeyGenerators._fallback === keyGenerators_1.KeyGenerators.uuid).toBeTrue();
    });
});
//# sourceMappingURL=keyGenerators.test.js.map