"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.withKeys = void 0;
const keyGenerators_1 = require("./keyGenerators");
/**
 * A simple key extractor/generator, intended for use with arrays of objects in React.  Guarantees unique keys.
 *
 * @param {KeyableObject[]} arr - The array to map keys for.
 * @param {boolean} [consistentStrategy=false] - If true, will try generators in turn until one yields all unique keys.
 * @param {GeneratorFunc[]} [generators=[]] - Generators to use for key creation.
 * @return KeyableObject[]
 */
const withKeys = (arr, consistentStrategy = false, ...generators) => {
    generators.push(keyGenerators_1.KeyGenerators._fallback());
    let keys = [];
    const isValidKey = (key) => key !== undefined &&
        typeof key !== 'object' &&
        String(key).length > 0 &&
        !keys.includes(key);
    let keyedArr = [];
    while (keys.length < arr.length) {
        keys = [];
        try {
            keyedArr = arr.map(element => {
                let key = '';
                const tools = [...generators];
                let generator = tools.shift();
                while (generator) {
                    key = generator(element);
                    if (isValidKey(key)) {
                        break;
                    }
                    else if (consistentStrategy) {
                        throw new Error();
                    }
                    else {
                        generator = tools.shift();
                    }
                }
                keys.push(key);
                element.key = key;
                return element;
            });
            break;
        }
        catch (e) {
            generators.shift();
            // continue;
        }
    }
    return keyedArr;
};
exports.withKeys = withKeys;
//# sourceMappingURL=withKeys.js.map